@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-10-06'; # DATE
-our $VERSION = '0.47'; # VERSION
+our $DATE = '2015-11-20'; # DATE
+our $VERSION = '0.48'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -308,7 +308,7 @@ sub _process_script {
               SHOW_RESULT:
                 {
                     my $res;
-                    last unless $eg->{'x.doc.show_result'} // 1;
+                    last unless $eg->{example_spec}{'x.doc.show_result'} // 1;
                     if (exists $eg->{result}) {
                         $res = $eg->{result};
                     } else {
@@ -670,7 +670,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.47 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-10-06.
+This document describes version 0.48 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-11-20.
 
 =head1 SYNOPSIS
 
